@@ -8,17 +8,17 @@
 #'
 #'  \code{(variable[1 : training.set])} to monitor performance of forecast over in-sample range.
 #' @param seasonal.factor logical or integer(s); \code{TRUE} (default) Automatically selects the best seasonal lag from the seasonality test.  To use weighted average of all seasonal lags set to \code{(seasonal.factor = FALSE)}.  Otherwise, directly input known frequency integer lag to use, i.e. \code{(seasonal.factor = 12)} for monthly data.  Multiple frequency integers can also be used, i.e. \code{(seasonal.factor = c(12, 24, 36))}
-#' @param best.periods integer; to be used in conjuction with \code{(seasonal.factor=FALSE)}, uses the \code{best.periods} number of detected seasonal lags instead of \code{ALL} lags when
+#' @param best.periods integer; [2] (default) used in conjuction with \code{(seasonal.factor = FALSE)}, uses the \code{best.periods} number of detected seasonal lags instead of \code{ALL} lags when
 #'
 #' \code{(seasonal.factor = FALSE)}.
 #' @param negative.values logical; \code{FALSE} (default) If the variable can be negative, set to
 #' \code{(negative.values = TRUE)}.
 #' @param method options: ("lin", "nonlin", "both"); \code{"nonlin"} (default)  To select the regression type of the component series, select \code{(method = "both")} where both linear and nonlinear estimates are generated.  To use a nonlineaer regression, set to
-#' \code{(method="nonlin")}; to use a linear regression set to \code{(method="lin")}.
+#' \code{(method = "nonlin")}; to use a linear regression set to \code{(method = "lin")}.
 #' @param dynamic logical; \code{FALSE} (default) To update the seasonal factor with each forecast point, set to \code{(dynamic = TRUE)}.  The default is \code{(dynamic = FALSE)} to retain the original seasonal factor from the inputted variable for all ensuing \code{h}.
 #' @param plot logical; \code{TRUE} (default) Returns the plot of all periods exhibiting seasonality and the \code{variable} level reference in upper panel.  Lower panel returns original data and forecast.
 #' @param seasonal.plot logical; \code{TRUE} (default) Adds the seasonality plot above the forecast.  Will be set to \code{FALSE} if no seasonality is detected or \code{seasonal.factor} is set to an integer value.
-#' @param intervals logical; \code{FALSE} (default) Plots the surrounding forecasts around the final estimate when \code{(intervals=TRUE)} and \code{(seasonal.factor = FALSE)}.  There are no other forecasts to plot when a single \code{seasonal.factor} is selected.
+#' @param intervals logical; \code{FALSE} (default) Plots the surrounding forecasts around the final estimate when \code{(intervals = TRUE)} and \code{(seasonal.factor = FALSE)}.  There are no other forecasts to plot when a single \code{seasonal.factor} is selected.
 #' @return Returns a vector of forecasts of length \code{(h)}.
 #' @note
 #' For monthly data series, increased accuracy may be realized from forcing seasonal factors to multiples of 12.  For example, if the best periods reported are: \{37, 47, 71, 73\}  use
@@ -45,11 +45,11 @@
 #'
 #' ## Linear NNS.ARMA using AirPassengers monthly data and 12, 24, and 36 period lags
 #' \dontrun{
-#' NNS.ARMA(AirPassengers, h = 45, training.set = 100, seasonal.factor = c(12, 24, 36), method = "lin")}
+#' NNS.ARMA(AirPassengers, h = 45, training.set = 120, seasonal.factor = c(12, 24, 36), method = "lin")}
 #'
 #' ## Nonlinear NNS.ARMA using AirPassengers monthly data and 2 best periods lag
 #' \dontrun{
-#' NNS.ARMA(AirPassengers, h = 45, training.set = 100, seasonal.factor = FALSE, best.periods = 2)}
+#' NNS.ARMA(AirPassengers, h = 45, training.set = 120, seasonal.factor = FALSE, best.periods = 2)}
 #'
 #' @export
 
@@ -60,13 +60,13 @@ NNS.ARMA <- function(variable,
                      h = 1,
                      training.set = NULL,
                      seasonal.factor = TRUE ,
-                     best.periods = NULL,
+                     best.periods = 2,
                      negative.values = FALSE,
                      method = "nonlin",
                      dynamic = FALSE,
                      plot = TRUE,
                      seasonal.plot = TRUE,
-                     intervals=FALSE){
+                     intervals = FALSE){
 
   if(intervals && is.numeric(seasonal.factor)){
     stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals=F" or "seasonal.factor=F"')
@@ -80,10 +80,11 @@ NNS.ARMA <- function(variable,
     stop('Hmmm...Seems you have "seasonal.factor" specified and "dynamic==TRUE".  Nothing dynamic about static seasonal factors!  Please set "dynamic=F" or "seasonal.factor=F"')
   }
 
-  if(!is.null(best.periods)){
+  if(!is.null(best.periods) && !is.numeric(seasonal.factor)){
     seasonal.factor = FALSE
   }
 
+
   variable = as.numeric(variable)
   OV = variable
 
@@ -108,12 +109,12 @@ NNS.ARMA <- function(variable,
       return(list(lag = 1, Weights = 1))
     }
 
-    if(ncol(M)>1){
-        if(seasonal.factor){
-            lag = seas.matrix$best.period
-            Weights = 1
-            return(list(lag = lag, Weights = Weights))
-        }
+    if(ncol(M) > 1){
+      if(seasonal.factor){
+        lag = seas.matrix$best.period
+        Weights = 1
+        return(list(lag = lag, Weights = Weights))
+      }
 
       # Determine lag from seasonality test
       if(!seasonal.factor){
@@ -126,6 +127,7 @@ NNS.ARMA <- function(variable,
     }
   }
 
+
   # Generator for 1:length(lag) vectors
   generate.vectors = function(l){
     Component.series = list()
@@ -134,145 +136,148 @@ NNS.ARMA <- function(variable,
     for (i in 1:length(l)){
       CS = rev(variable[seq(length(variable)+1, 1, -l[i])])
       CS = CS[!is.na(CS)]
-      Component.series[[paste('Series.',i,sep="")]] <- CS
-      Component.index[[paste('Index.',i,sep="")]] <- (1 : length(CS))
+      Component.series[[paste('Series.', i, sep = "")]] <- CS
+      Component.index[[paste('Index.', i, sep = "")]] <- (1 : length(CS))
     }
     return(list(Component.index = Component.index, Component.series = Component.series))
   }
 
 
-    if(is.numeric(seasonal.factor)){
-      M <- t(seasonal.factor)
-      lag = seasonal.factor
-      output = numeric()
-      for(i in 1 : length(seasonal.factor)){
-        rev.var = variable[seq(length(variable), 1, -i)]
-        output[i] = abs(sd(rev.var) / mean(rev.var))
-      }
+  if(is.numeric(seasonal.factor)){
+    M <- t(seasonal.factor)
+    lag = seasonal.factor
+    output = numeric(length(seasonal.factor))
+    for(i in 1 : length(seasonal.factor)){
+      rev.var = variable[seq(length(variable), 1, -i)]
+      output[i] = abs(sd(rev.var) / mean(rev.var))
+    }
 
-      Relative.seasonal = output / abs(sd(variable)/mean(variable))
-      Seasonal.weighting = 1 / Relative.seasonal
-      Observation.weighting = 1 / sqrt(seasonal.factor)
-      Weights = (Seasonal.weighting * Observation.weighting) / sum(Observation.weighting * Seasonal.weighting)
-      seasonal.plot = FALSE
+    Relative.seasonal = output / abs(sd(variable)/mean(variable))
+    Seasonal.weighting = 1 / Relative.seasonal
+    Observation.weighting = 1 / sqrt(seasonal.factor)
+    Weights = (Seasonal.weighting * Observation.weighting) / sum(Observation.weighting * Seasonal.weighting)
+    seasonal.plot = FALSE
+  } else {
+    seas.matrix = NNS.seas(variable, plot=FALSE)
+    if(!is.list(seas.matrix)){
+      M <- t(1)
     } else {
-        seas.matrix = NNS.seas(variable, plot=FALSE)
-        if(!is.list(seas.matrix)){
-          M <- t(1)
-        } else {
-            if(is.null(best.periods)){
-              M <- seas.matrix$all.periods
-            } else {
-              M <- seas.matrix$all.periods[1 : best.periods, ]
-            }
+      if(is.null(best.periods)){
+        M <- seas.matrix$all.periods
+      } else {
+        if(!seasonal.factor && is.numeric(best.periods) && length(seas.matrix$all.periods$Period) < best.periods){
+          best.periods = length(seas.matrix$all.periods$Period)
         }
+        M <- seas.matrix$all.periods[1 : best.periods, ]
+      }
+    }
+
+    ASW = ARMA.seas.weighting()
+    lag = ASW$lag
+    Weights = ASW$Weights
+  }
+
+  Estimate.band = list()
+
+
+  # Regression for each estimate in h
+  for (j in 1 : h){
+    ## Regenerate seasonal.factor if dynamic
+    if(dynamic){
+      seas.matrix = NNS.seas(variable, plot=FALSE)
+      if(!is.list(seas.matrix)){
+        M <- t(1)
+      } else {
+        if(is.null(best.periods)){
+          M<- seas.matrix$all.periods
+        } else {
+          M<- seas.matrix$all.periods[1 : best.periods, ]
+        }
+      }
 
       ASW = ARMA.seas.weighting()
       lag = ASW$lag
       Weights = ASW$Weights
     }
 
-    Estimate.band = list()
+    ## Generate vectors for 1:lag
+    GV = generate.vectors(lag)
+    Component.index = GV$Component.index
+    Component.series = GV$Component.series
+
+    ## Regression on Component Series
+    Regression.Estimates = numeric()
 
 
-    # Regression for each estimate in h
-    for (j in 1 : h){
-      ## Regenerate seasonal.factor if dynamic
-      if(dynamic){
-        seas.matrix = NNS.seas(variable, plot=FALSE)
-        if(!is.list(seas.matrix)){
-          M <- t(1)
+    if(method == 'nonlin' | method == 'both'){
+      for(i in 1 : length(lag)){
+        x = Component.index[[i]] ; y = Component.series[[i]]
+        last.x = tail(x, 1)
+        last.y = tail(y, 1)
+
+        if(last.x <= 4){
+          order = 1
         } else {
-            if(is.null(best.periods)){
-                M<- seas.matrix$all.periods
-            } else {
-                M<- seas.matrix$all.periods[1 : best.periods, ]
-            }
+          order = NULL
         }
 
-        ASW = ARMA.seas.weighting()
-        lag = ASW$lag
-        Weights = ASW$Weights
+        ## Skeleton NNS regression for NNS.ARMA
+        reg.points = tail(NNS.reg(x, y, return.values = FALSE, order = order, plot = FALSE, noise.reduction = 'off', multivariate.call = TRUE), 2)
+
+        run = diff(reg.points$x)
+        rise = diff(reg.points$y)
+
+        Regression.Estimates[i] = last.y + (rise / run)
       }
 
-      ## Generate vectors for 1:lag
-      GV = generate.vectors(lag)
-      Component.index = GV$Component.index
-      Component.series = GV$Component.series
-
-      ## Regression on Component Series
-      Regression.Estimates = numeric()
-      Coefficients = numeric()
-
-      if(method == 'nonlin' | method == 'both'){
-        for(i in 1 : length(lag)){
-          x = Component.index[[i]] ; y=Component.series[[i]]
-          last.x = tail(x, 1)
-          last.y = tail(y, 1)
-
-          if(last.x <= 4){
-            order=1
-          } else {
-            order=NULL
-          }
-
-          ## Skeleton NNS regression for NNS.ARMA
-          reg.points = tail(NNS.reg(x, y, return.values = FALSE, order =order, plot = FALSE, noise.reduction = 'off', multivariate.call = TRUE), 2)
-
-          run = diff(reg.points$x)
-          rise = diff(reg.points$y)
-
-          Regression.Estimates[i] = last.y + (rise / run)
-        }
-
-        if(!negative.values){
-          Regression.Estimates = pmax(0, Regression.Estimates)
-        }
-
-        NL.Regression.Estimates = Regression.Estimates
-        Nonlin.estimates = sum(Regression.Estimates * Weights)
-
-      }#Linear == F
-
-      if(method =='lin' | method == 'both'){
-
-        for(i in 1 : length(lag)){
-          last.x = tail(Component.index[[i]], 1)
-          coefs = coef(lm(Component.series[[i]] ~ Component.index[[i]]))
-          Regression.Estimates[i] = coefs[1] + (coefs[2] * (last.x + 1))
-        }
-
-        if(!negative.values){
-          Regression.Estimates = pmax(0, Regression.Estimates)
-        }
-
-        L.Regression.Estimates = Regression.Estimates
-        Lin.estimates = sum(Regression.Estimates * Weights)
-
-      }#Linear == T
-
-      if(intervals){
-        if(method == 'both'){
-          Estimate.band[[j]] = c(NL.Regression.Estimates, L.Regression.Estimates)
-        }
-        if(method == 'nonlin'){
-          Estimate.band[[j]] = NL.Regression.Estimates
-        }
-        if(method == 'lin'){
-          Estimate.band[[j]] = L.Regression.Estimates
-        }
+      if(!negative.values){
+        Regression.Estimates = pmax(0, Regression.Estimates)
       }
 
+      NL.Regression.Estimates = Regression.Estimates
+      Nonlin.estimates = sum(Regression.Estimates * Weights)
+
+    }#Linear == F
+
+    if(method == 'lin' | method == 'both'){
+
+      for(i in 1 : length(lag)){
+        last.x = tail(Component.index[[i]], 1)
+        coefs = coef(lm(Component.series[[i]] ~ Component.index[[i]]))
+        Regression.Estimates[i] = coefs[1] + (coefs[2] * (last.x + 1))
+      }
+
+      if(!negative.values){
+        Regression.Estimates = pmax(0, Regression.Estimates)
+      }
+
+      L.Regression.Estimates = Regression.Estimates
+      Lin.estimates = sum(Regression.Estimates * Weights)
+
+    }#Linear == T
+
+    if(intervals){
       if(method == 'both'){
-        Estimates[j] = mean(c(Lin.estimates, Nonlin.estimates))
-      } else {
-        Estimates[j] = sum(Regression.Estimates * Weights)
+        Estimate.band[[j]] = c(NL.Regression.Estimates, L.Regression.Estimates)
       }
+      if(method == 'nonlin'){
+        Estimate.band[[j]] = NL.Regression.Estimates
+      }
+      if(method == 'lin'){
+        Estimate.band[[j]] = L.Regression.Estimates
+      }
+    }
 
-      variable = c(variable, Estimates[j])
-      FV = variable
+    if(method == 'both'){
+      Estimates[j] = mean(c(Lin.estimates, Nonlin.estimates))
+    } else {
+      Estimates[j] = sum(Regression.Estimates * Weights)
+    }
 
-    } # j loop
+    variable = c(variable, Estimates[j])
+    FV = variable
+
+  } # j loop
 
 
   #### PLOTTING
@@ -281,14 +286,14 @@ NNS.ARMA <- function(variable,
       par(mfrow = c(2, 1))
       if(ncol(M) > 1){
         plot(M[ , Period], M[ , Coefficient.of.Variance],
-           xlab = "Period", ylab = "Coefficient of Variance", main = "Seasonality Test", ylim = c(0, 2 * M[1, Variable.Coefficient.of.Variance]))
+             xlab = "Period", ylab = "Coefficient of Variance", main = "Seasonality Test", ylim = c(0, 2 * M[1, Variable.Coefficient.of.Variance]))
         points(M[1, Period], M[1, Coefficient.of.Variance], pch = 19, col = 'red')
         abline(h = M[1, Variable.Coefficient.of.Variance], col = "red", lty = 5)
         text((M[ , min(Period)] + M[ , max(Period)]) / 2, M[1, Variable.Coefficient.of.Variance], pos = 3, "Variable Coefficient of Variance", col = 'red')
       } else {
         plot(1, 1, pch = 19, col = 'blue', xlab = "Period", ylab = "Coefficient of Variance", main = "Seasonality Test",
-           ylim = c(0, 2 * abs(sd(FV) / mean(FV))))
-        text(1, abs(sd(FV) / mean(FV)), pos = 3,"NO SEASONALITY DETECTED", col = 'red')
+             ylim = c(0, 2 * abs(sd(FV) / mean(FV))))
+        text(1, abs(sd(FV) / mean(FV)), pos = 3, "NO SEASONALITY DETECTED", col = 'red')
       }
     }
 
@@ -298,8 +303,8 @@ NNS.ARMA <- function(variable,
     }
 
     plot(OV, type = 'l', lwd = 2, main = "NNS.ARMA Forecast", col = 'steelblue',
-          xlim = c(1, max((training.set + h), length(OV))),
-          ylab = label, ylim = c(min(Estimates, OV), max(OV, Estimates)))
+         xlim = c(1, max((training.set + h), length(OV))),
+         ylab = label, ylim = c(min(Estimates, OV), max(OV, Estimates)))
 
     if(intervals){
       for(i in 1 : h){
@@ -315,12 +320,12 @@ NNS.ARMA <- function(variable,
         lines((training.set + 1) : (training.set + h), Estimates, type = 'l',lwd = 2, lty = 3, col = 'red')
 
         segments(training.set, FV[training.set], training.set + 1, Estimates[1], lwd = 2, lty = 3, col = 'red')
-        legend('topleft', bty = 'n', legend = c("Original", paste0("Forecast ", h," period(s)")), lty = c(1, 2), col = c('steelblue', 'red'), lwd = 2)
+        legend('topleft', bty = 'n', legend = c("Original", paste0("Forecast ", h, " period(s)")), lty = c(1, 2), col = c('steelblue', 'red'), lwd = 2)
       } else {
         lines((training.set + 1) : (training.set + h), Estimates, type = 'l', lwd = 2, lty = 1, col = 'red')
 
         segments(training.set, FV[training.set], training.set + 1, Estimates[1], lwd = 2, lty = 1, col = 'red')
-        legend('topleft', bty = 'n', legend = c("Original", paste0("Forecast ", h," period(s)")),lty = c(1, 1), col = c('steelblue', 'red'), lwd = 2)
+        legend('topleft', bty = 'n', legend = c("Original", paste0("Forecast ", h, " period(s)")),lty = c(1, 1), col = c('steelblue', 'red'), lwd = 2)
       }
 
 
